PluginManager/PluginRepositoryDialog.py

changeset 3670
f0cb7579c0b4
parent 3656
441956d8fce5
child 3676
2f62b060a931
--- a/PluginManager/PluginRepositoryDialog.py	Sat Jul 05 11:41:14 2014 +0200
+++ b/PluginManager/PluginRepositoryDialog.py	Sat Jul 05 12:13:23 2014 +0200
@@ -40,7 +40,7 @@
 
 import UI.PixmapCache
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
@@ -791,10 +791,10 @@
     
     def __startPluginInstall(self):
         """
         Private slot to start the eric5 plugin installation dialog.
         """
         proc = QProcess()
-        applPath = os.path.join(getConfig("ericDir"), "eric5_plugininstall.py")
+        applPath = os.path.join(getConfig("ericDir"), "eric6_plugininstall.py")
         
         args = []
         args.append(applPath)
@@ -791,10 +791,10 @@
     def __startPluginInstall(self):
         """
-        Private slot to start the eric5 plugin installation dialog.
+        Private slot to start the eric6 plugin installation dialog.
         """
         proc = QProcess()

eric ide

mercurial